@@ -1,31 +1,31 @@
-#  Licensed to the Apache Software Foundation (ASF) under one
-#  or more contributor license agreements.  See the NOTICE file
-#  distributed with this work for additional information
-#  regarding copyright ownership.  The ASF licenses this file
-#  to you under the Apache License, Version 2.0 (the
-#  "License"); you may not use this file except in compliance
-#  with the License.  You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one
+# or more contributor license agreements.  See the NOTICE file
+# distributed with this work for additional information
+# regarding copyright ownership.  The ASF licenses this file
+# to you under the Apache License, Version 2.0 (the
+# "License"); you may not use this file except in compliance
+# with the License.  You may obtain a copy of the License at
 #
-#    http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
-#  Unless required by applicable law or agreed to in writing,
-#  software distributed under the License is distributed on an
-#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
-#  KIND, either express or implied.  See the License for the
-#  specific language governing permissions and limitations
-#  under the License.
+# Unless required by applicable law or agreed to in writing,
+# software distributed under the License is distributed on an
+# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+# KIND, either express or implied.  See the License for the
+# specific language governing permissions and limitations
+# under the License.
 
 
 spark_dependencies <- function(spark_version, scala_version, ...) {
   if (spark_version[1, 1] == "3") {
-    spark_version <- "3.0"
+    spark_version <- spark_version
     scala_version <- scala_version %||% "2.12"
   } else {
     stop("Unsupported Spark version: ", spark_version)
   }
 
   packages <- c(
-    "org.datasyslab:geotools-wrapper:1.6.0-28.2"
+    "org.datasyslab:geotools-wrapper:1.7.1-28.5"
   )
   jars <- NULL
 
@@ -38,11 +38,11 @@ spark_dependencies <- function(spark_version, scala_version, ...) {
       paste0(
         "org.apache.sedona:sedona-",
         c("spark-shaded"),
-        sprintf("-%s_%s:1.6.0", spark_version, scala_version)
+        sprintf("-%s_%s:1.7.1", spark_version, scala_version)
       ),
       packages
     )
-    cli::cli_alert_info(sprintf("Using Sedona jars versions: %s etc.", packages[1]))
+    cli::cli_alert_info(sprintf("Using Sedona jar version: %s", packages[1]))
   }
 
   spark_dependency(
@@ -57,8 +57,8 @@ spark_dependencies <- function(spark_version, scala_version, ...) {
 sedona_initialize_spark_connection <- function(sc) {
   invoke_static(
     sc,
-    "org.apache.sedona.sql.utils.SedonaSQLRegistrator",
-    "registerAll",
+    "org.apache.sedona.spark.SedonaContext",
+    "create",
     spark_session(sc),
     "r"
   )
