@@ -29,6 +29,7 @@ import java.util.List;
 import java.util.stream.Collectors;
 import org.apache.commons.lang3.tuple.Pair;
 import org.apache.sedona.common.geometryObjects.Circle;
+import org.apache.sedona.common.geometryObjects.Geography;
 import org.apache.sedona.common.sphere.Spheroid;
 import org.apache.sedona.common.subDivide.GeometrySubDivider;
 import org.apache.sedona.common.utils.*;
@@ -80,6 +81,123 @@ public class Functions {
     return geometry.getArea();
   }
 
+  public static Geometry labelPoint(Geometry geometry) {
+    return labelPoint(geometry, 16, 0.2);
+  }
+
+  public static Geometry labelPoint(Geometry geometry, int gridResolution) {
+    return labelPoint(geometry, gridResolution, 0.2);
+  }
+
+  public static Geometry labelPoint(
+      Geometry geometry, int gridResolution, double goodnessThreshold) {
+    if (geometry.getArea() <= 0) {
+      throw new IllegalArgumentException("Geometry must have a positive area");
+    }
+
+    GeometryFactory geometryFactory = new GeometryFactory();
+
+    // Find the largest polygon
+    Polygon largestPolygon = findLargestPolygon(geometry);
+
+    if (largestPolygon == null) {
+      throw new IllegalArgumentException("Geometry must contain at least one Polygon");
+    }
+
+    return polygonToLabel(largestPolygon, gridResolution, goodnessThreshold, geometryFactory);
+  }
+
+  private static Polygon findLargestPolygon(Geometry geometry) {
+    if (geometry instanceof Polygon) {
+      return (Polygon) geometry;
+    }
+
+    if (geometry instanceof GeometryCollection) {
+      GeometryCollection gc = (GeometryCollection) geometry;
+      Polygon largestPolygon = null;
+      double maxArea = Double.MIN_VALUE;
+
+      for (int i = 0; i < gc.getNumGeometries(); i++) {
+        Geometry subGeometry = gc.getGeometryN(i);
+        Polygon candidate = findLargestPolygon(subGeometry);
+
+        if (candidate != null && candidate.getArea() > maxArea) {
+          largestPolygon = candidate;
+          maxArea = candidate.getArea();
+        }
+      }
+      return largestPolygon;
+    }
+
+    return null;
+  }
+
+  private static Point polygonToLabel(
+      Polygon polygon,
+      int gridResolution,
+      double goodnessThreshold,
+      GeometryFactory geometryFactory) {
+    if (polygon.getArea() <= 0) {
+      throw new IllegalArgumentException("Polygon must have a positive area");
+    }
+
+    Envelope env = polygon.getEnvelopeInternal();
+    double xmin = env.getMinX();
+    double ymin = env.getMinY();
+    double xmax = env.getMaxX();
+    double ymax = env.getMaxY();
+
+    // Calculate step size based on grid resolution
+    double stepSizeX = (xmax - xmin) / gridResolution;
+    double stepSizeY = (ymax - ymin) / gridResolution;
+
+    Point centroid = polygon.getCentroid();
+    double radius = Math.sqrt(polygon.getArea() / Math.PI);
+    goodnessThreshold = radius * goodnessThreshold;
+
+    double bestGoodness = labelGoodness(polygon, centroid);
+
+    if (bestGoodness < goodnessThreshold) {
+      for (int x = 0; x < gridResolution; x++) {
+        for (int y = 0; y < gridResolution; y++) {
+          double candidateX = xmin + x * stepSizeX;
+          double candidateY = ymin + y * stepSizeY;
+          Point candidate = geometryFactory.createPoint(new Coordinate(candidateX, candidateY));
+
+          double candidateGoodness = labelGoodness(polygon, candidate);
+
+          if (candidateGoodness > bestGoodness) {
+            centroid = candidate;
+            bestGoodness = candidateGoodness;
+          }
+        }
+      }
+    }
+
+    return centroid;
+  }
+
+  private static double labelGoodness(Geometry geometry, Point point) {
+    if (!geometry.intersects(point)) {
+      return 0.0;
+    }
+
+    double closest = Double.POSITIVE_INFINITY;
+    Coordinate[] coordinates = geometry.getCoordinates();
+
+    for (Coordinate coord : coordinates) {
+      double dx = coord.x - point.getX();
+      double dy = coord.y - point.getY();
+      double distanceSquared = dx * dx + dy * dy;
+
+      if (distanceSquared < closest) {
+        closest = distanceSquared;
+      }
+    }
+
+    return Math.sqrt(closest);
+  }
+
   public static double azimuth(Geometry left, Geometry right) {
     Coordinate leftCoordinate = left.getCoordinate();
     Coordinate rightCoordinate = right.getCoordinate();
@@ -659,6 +777,10 @@ public class Functions {
     return GeomUtils.getEWKT(geometry);
   }
 
+  public static String asEWKT(Geography geography) {
+    return asEWKT(geography.getGeometry());
+  }
+
   public static String asWKT(Geometry geometry) {
     return GeomUtils.getWKT(geometry);
   }
@@ -667,6 +789,10 @@ public class Functions {
     return GeomUtils.getEWKB(geometry);
   }
 
+  public static byte[] asEWKB(Geography geography) {
+    return asEWKB(geography.getGeometry());
+  }
+
   public static String asHexEWKB(Geometry geom, String endian) {
     if (endian.equalsIgnoreCase("NDR")) {
       return GeomUtils.getHexEWKB(geom, ByteOrderValues.LITTLE_ENDIAN);
@@ -1039,6 +1165,36 @@ public class Functions {
     return geometry.getFactory().createGeometryCollection();
   }
 
+  public static Geometry[] lineSegments(Geometry geometry, boolean lenient) {
+    if (!(geometry instanceof LineString)) {
+      if (lenient) {
+        return new Geometry[] {};
+      } else {
+        throw new IllegalArgumentException(
+            "Geometry is not a LineString. This function expects input geometry to be a LineString.");
+      }
+    }
+
+    LineString line = (LineString) geometry;
+    Coordinate[] coords = line.getCoordinates();
+    if (coords.length == 2 || coords.length == 0) {
+      return new Geometry[] {line};
+    }
+
+    GeometryFactory geometryFactory = geometry.getFactory();
+    Geometry[] resultArray = new Geometry[coords.length - 1];
+    for (int i = 1; i < coords.length; i++) {
+      resultArray[i - 1] =
+          geometryFactory.createLineString(new Coordinate[] {coords[i - 1], coords[i]});
+    }
+
+    return resultArray;
+  }
+
+  public static Geometry[] lineSegments(Geometry geometry) {
+    return lineSegments(geometry, true);
+  }
+
   public static Geometry minimumBoundingCircle(Geometry geometry, int quadrantSegments) {
     MinimumBoundingCircle minimumBoundingCircle = new MinimumBoundingCircle(geometry);
     Coordinate centre = minimumBoundingCircle.getCentre();
