@@ -90,6 +90,7 @@ public class Catalog {
       new Functions.ST_GeometryType(),
       new Functions.ST_InterpolatePoint(),
       new Functions.ST_Intersection(),
+      new Functions.ST_LabelPoint(),
       new Functions.ST_Length(),
       new Functions.ST_Length2D(),
       new Functions.ST_LengthSpheroid(),
@@ -101,6 +102,7 @@ public class Catalog {
       new Functions.ST_FlipCoordinates(),
       new Functions.ST_GeoHash(),
       new Functions.ST_Perimeter(),
+      new Functions.ST_Perimeter2D(),
       new Functions.ST_PointOnSurface(),
       new Functions.ST_Scale(),
       new Functions.ST_ScaleGeom(),
@@ -155,6 +157,7 @@ public class Catalog {
       new Functions.ST_SetPoint(),
       new Functions.ST_LineFromMultiPoint(),
       new Functions.ST_LineMerge(),
+      new Functions.ST_LineSegments(),
       new Functions.ST_LineSubstring(),
       new Functions.ST_HasZ(),
       new Functions.ST_HasM(),
