@@ -16,7 +16,7 @@
 #  under the License.
 
 from .geo_json_reader import GeoJsonReader
-from .wkt_reader import WktReader
 from .wkb_reader import WkbReader
+from .wkt_reader import WktReader
 
-__all__ = ["GeoJsonReader", 'WktReader', 'WkbReader']
+__all__ = ["GeoJsonReader", "WktReader", "WkbReader"]
