@@ -17,13 +17,14 @@
 
 import os
 
-from sedona.core.SpatialRDD import RectangleRDD
-from sedona.core.enums import IndexType, FileDataSplitter
-from sedona.core.geom.envelope import Envelope
-from sedona.core.spatialOperator import RangeQuery
 from tests.test_base import TestBase
 from tests.tools import tests_resource
 
+from sedona.core.enums import FileDataSplitter, IndexType
+from sedona.core.geom.envelope import Envelope
+from sedona.core.spatialOperator import RangeQuery
+from sedona.core.SpatialRDD import RectangleRDD
+
 inputLocation = os.path.join(tests_resource, "zcta510-small.csv")
 queryWindowSet = os.path.join(tests_resource, "zcta510-small.csv")
 offset = 0
@@ -48,21 +49,30 @@ class TestRectangleRange(TestBase):
 
         for i in range(self.loop_times):
             result_size = RangeQuery.SpatialRangeQuery(
-                spatial_rdd, self.query_envelope, False, False).count()
+                spatial_rdd, self.query_envelope, False, False
+            ).count()
             assert result_size == 193
 
-        assert RangeQuery.SpatialRangeQuery(
-            spatial_rdd, self.query_envelope, False, False).take(10)[1].getUserData() is not None
+        assert (
+            RangeQuery.SpatialRangeQuery(spatial_rdd, self.query_envelope, False, False)
+            .take(10)[1]
+            .getUserData()
+            is not None
+        )
 
     def test_spatial_range_query_using_index(self):
-        spatial_rdd = RectangleRDD(
-            self.sc, inputLocation, offset, splitter, True)
+        spatial_rdd = RectangleRDD(self.sc, inputLocation, offset, splitter, True)
 
         spatial_rdd.buildIndex(IndexType.RTREE, False)
         for i in range(self.loop_times):
             result_size = RangeQuery.SpatialRangeQuery(
-                spatial_rdd, self.query_envelope, False, True).count()
+                spatial_rdd, self.query_envelope, False, True
+            ).count()
             assert result_size == 193
 
-        assert RangeQuery.SpatialRangeQuery(spatial_rdd, self.query_envelope, False, True).take(10)[1].getUserData()\
-               is not None
+        assert (
+            RangeQuery.SpatialRangeQuery(spatial_rdd, self.query_envelope, False, True)
+            .take(10)[1]
+            .getUserData()
+            is not None
+        )
