@@ -101,6 +101,32 @@ public class UDFsV2 {
         Functions.affine(GeometrySerde.deserGeoJson(geometry), a, b, d, e, xOff, yOff));
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geom"},
+      argTypes = {"Geometry"},
+      returnTypes = "Geometry")
+  public static String ST_LabelPoint(String geom) {
+    return GeometrySerde.serGeoJson(Functions.labelPoint(GeometrySerde.deserGeoJson(geom)));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geom", "gridResolution"},
+      argTypes = {"Geometry", "int"},
+      returnTypes = "Geometry")
+  public static String ST_LabelPoint(String geom, int gridResolution) {
+    return GeometrySerde.serGeoJson(
+        Functions.labelPoint(GeometrySerde.deserGeoJson(geom), gridResolution));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geom", "gridResolution", "goodnessThreshold"},
+      argTypes = {"Geometry", "int", "double"},
+      returnTypes = "Geometry")
+  public static String ST_LabelPoint(String geom, int gridResolution, double goodnessThreshold) {
+    return GeometrySerde.serGeoJson(
+        Functions.labelPoint(GeometrySerde.deserGeoJson(geom), gridResolution, goodnessThreshold));
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geom1", "geom2"},
       argTypes = {"Geometry", "Geometry"})
@@ -963,6 +989,30 @@ public class UDFsV2 {
     return Functions.perimeter(GeometrySerde.deserGeoJson(geometry), use_spheroid, lenient);
   }
 
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry"},
+      argTypes = {"Geometry"},
+      returnTypes = "double")
+  public static double ST_Perimeter2D(String geometry) {
+    return Functions.perimeter(GeometrySerde.deserGeoJson(geometry));
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "use_spheroid"},
+      argTypes = {"Geometry", "boolean"},
+      returnTypes = "double")
+  public static double ST_Perimeter2D(String geometry, boolean use_spheroid) {
+    return Functions.perimeter(GeometrySerde.deserGeoJson(geometry), use_spheroid);
+  }
+
+  @UDFAnnotations.ParamMeta(
+      argNames = {"geometry", "use_spheroid", "lenient"},
+      argTypes = {"Geometry", "boolean", "boolean"},
+      returnTypes = "double")
+  public static double ST_Perimeter2D(String geometry, boolean use_spheroid, boolean lenient) {
+    return Functions.perimeter(GeometrySerde.deserGeoJson(geometry), use_spheroid, lenient);
+  }
+
   @UDFAnnotations.ParamMeta(
       argNames = {"geometry"},
       argTypes = {"Geometry"},
