@@ -18,6 +18,7 @@
  */
 package org.apache.spark.sql.sedona_sql.expressions
 
+import org.apache.sedona.common.geometryObjects.Geography
 import org.apache.sedona.common.{Functions, FunctionsGeoTools}
 import org.apache.sedona.common.sphere.{Haversine, Spheroid}
 import org.apache.sedona.common.utils.{InscribedCircle, ValidDetail}
@@ -35,6 +36,17 @@ import org.apache.spark.sql.sedona_sql.expressions.InferrableFunctionConverter._
 import org.apache.spark.unsafe.types.UTF8String
 import org.apache.spark.util.Utils
 
+case class ST_LabelPoint(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction1(Functions.labelPoint),
+      inferrableFunction2(Functions.labelPoint),
+      inferrableFunction3(Functions.labelPoint)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 /**
  * Return the distance between two geometries.
  *
@@ -495,7 +507,9 @@ case class ST_AsBinary(inputExpressions: Seq[Expression])
 }
 
 case class ST_AsEWKB(inputExpressions: Seq[Expression])
-    extends InferredExpression(Functions.asEWKB _) {
+    extends InferredExpression(
+      (geom: Geometry) => Functions.asEWKB(geom),
+      (geog: Geography) => Functions.asEWKB(geog)) {
 
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
@@ -719,6 +733,15 @@ case class ST_MMax(inputExpressions: Seq[Expression])
   }
 }
 
+case class ST_LineSegments(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction2(Functions.lineSegments),
+      inferrableFunction1(Functions.lineSegments)) {
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 /**
  * Return a linestring being a substring of the input one starting and ending at the given
  * fractions of total 2d length. Second and third arguments are Double values between 0 and 1.
@@ -1004,6 +1027,17 @@ case class ST_Perimeter(inputExpressions: Seq[Expression])
   }
 }
 
+case class ST_Perimeter2D(inputExpressions: Seq[Expression])
+    extends InferredExpression(
+      inferrableFunction3(Functions.perimeter),
+      inferrableFunction2(Functions.perimeter),
+      inferrableFunction1(Functions.perimeter)) {
+
+  protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
+    copy(inputExpressions = newChildren)
+  }
+}
+
 case class ST_Points(inputExpressions: Seq[Expression])
     extends InferredExpression(Functions.points _) {
 
@@ -1213,7 +1247,9 @@ case class ST_Force_2D(inputExpressions: Seq[Expression])
  * @param inputExpressions
  */
 case class ST_AsEWKT(inputExpressions: Seq[Expression])
-    extends InferredExpression(Functions.asEWKT _) {
+    extends InferredExpression(
+      (geom: Geometry) => Functions.asEWKT(geom),
+      (geog: Geography) => Functions.asEWKT(geog)) {
 
   protected def withNewChildrenInternal(newChildren: IndexedSeq[Expression]) = {
     copy(inputExpressions = newChildren)
@@ -1694,7 +1730,7 @@ case class ST_DelaunayTriangles(inputExpressions: Seq[Expression])
 }
 
 /**
- * Return the number of ddimensions in geometry.
+ * Return the number of dimensions in geometry.
  *
  * @param inputExpressions
  */
