@@ -16,7 +16,6 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.sedona.sql
 
 import org.apache.sedona.common.geometrySerde.GeometrySerializer
@@ -38,25 +37,25 @@ class SerdeAwareFunctionSpec extends TestBaseScala {
       val factory = new GeometryFactory
       val stubGeom = factory.createPoint(new Coordinate(1, 2))
       val mocked = mockStatic(classOf[GeometrySerializer])
-      mocked.when(() => GeometrySerializer.deserialize(any(classOf[Array[Byte]]))).thenReturn(stubGeom)
-      mocked.when(() => GeometrySerializer.serialize(any(classOf[Geometry]))).thenReturn(Array[Byte](1, 2, 3))
+      mocked
+        .when(() => GeometrySerializer.deserialize(any(classOf[Array[Byte]])))
+        .thenReturn(stubGeom)
+      mocked
+        .when(() => GeometrySerializer.serialize(any(classOf[Geometry])))
+        .thenReturn(Array[Byte](1, 2, 3))
 
-      val expr = ST_Union(Seq(
-        ST_Buffer(Seq(ST_GeomFromText(Seq(Literal("POINT (1 2)"), Literal(0))), Literal(1.0))),
-        ST_Point(Seq(Literal(1.0), Literal(2.0), Literal(null)))
-      ))
+      val expr = ST_Union(
+        Seq(
+          ST_Buffer(Seq(ST_GeomFromText(Seq(Literal("POINT (1 2)"), Literal(0))), Literal(1.0))),
+          ST_Point(Seq(Literal(1.0), Literal(2.0), Literal(null)))))
 
       try {
         // Evaluate an expression
         expr.eval(null)
 
         // Verify number of invocations
-        mocked.verify(
-          () => GeometrySerializer.deserialize(any(classOf[Array[Byte]])),
-          atMost(0))
-        mocked.verify(
-          () => GeometrySerializer.serialize(any(classOf[Geometry])),
-          atMost(1))
+        mocked.verify(() => GeometrySerializer.deserialize(any(classOf[Array[Byte]])), atMost(0))
+        mocked.verify(() => GeometrySerializer.serialize(any(classOf[Geometry])), atMost(1))
       } finally {
         // Undo the mock
         mocked.close()
@@ -76,24 +75,22 @@ class SerdeAwareFunctionSpec extends TestBaseScala {
           |0 1 2 3
           |""".stripMargin
       val mocked = mockStatic(classOf[Serde])
-      mocked.when(() => Serde.deserialize(any(classOf[Array[Byte]]))).thenReturn(fromArcInfoAsciiGrid(ascGrid.getBytes))
-      mocked.when(() => Serde.serialize(any(classOf[GridCoverage2D]))).thenReturn(Array[Byte](1, 2, 3))
+      mocked
+        .when(() => Serde.deserialize(any(classOf[Array[Byte]])))
+        .thenReturn(fromArcInfoAsciiGrid(ascGrid.getBytes))
+      mocked
+        .when(() => Serde.serialize(any(classOf[GridCoverage2D])))
+        .thenReturn(Array[Byte](1, 2, 3))
 
-      val expr = RS_NumBands(Seq(
-        RS_FromArcInfoAsciiGrid(Seq(Literal(ascGrid.getBytes)))
-      ))
+      val expr = RS_NumBands(Seq(RS_FromArcInfoAsciiGrid(Seq(Literal(ascGrid.getBytes)))))
 
       try {
         // Evaluate an expression
         expr.eval(null)
 
         // Verify number of invocations
-        mocked.verify(
-          () => Serde.deserialize(any(classOf[Array[Byte]])),
-          atMost(0))
-        mocked.verify(
-          () => Serde.serialize(any(classOf[GridCoverage2D])),
-          atMost(1))
+        mocked.verify(() => Serde.deserialize(any(classOf[Array[Byte]])), atMost(0))
+        mocked.verify(() => Serde.serialize(any(classOf[GridCoverage2D])), atMost(1))
       } finally {
         // Undo the mock
         mocked.close()
