@@ -20,17 +20,17 @@ package org.apache.spark.sql.execution.datasources.parquet
 
 import org.apache.parquet.column.Dictionary
 import org.apache.parquet.io.api.{Binary, Converter, GroupConverter, PrimitiveConverter}
+import org.apache.parquet.schema.LogicalTypeAnnotation.TimeUnit
+import org.apache.parquet.schema.LogicalTypeAnnotation.TimestampLogicalTypeAnnotation
 import org.apache.parquet.schema.OriginalType.LIST
 import org.apache.parquet.schema.PrimitiveType.PrimitiveTypeName._
 import org.apache.parquet.schema.{GroupType, OriginalType, Type}
 import org.apache.spark.internal.Logging
 import org.apache.spark.sql.catalyst.InternalRow
 import org.apache.spark.sql.catalyst.expressions._
-import org.apache.spark.sql.catalyst.types.{PhysicalByteType, PhysicalShortType}
-import org.apache.spark.sql.catalyst.util.RebaseDateTime.RebaseSpec
 import org.apache.spark.sql.catalyst.util.{ArrayBasedMapData, CaseInsensitiveMap, DateTimeUtils, GenericArrayData}
-import org.apache.spark.sql.execution.datasources.DataSourceUtils
 import org.apache.spark.sql.internal.SQLConf
+import org.apache.spark.sql.internal.SQLConf.LegacyBehaviorPolicy
 import org.apache.spark.sql.sedona_sql.UDT.GeometryUDT
 import org.apache.spark.sql.types._
 import org.apache.spark.unsafe.types.UTF8String
@@ -79,11 +79,10 @@ import scala.collection.mutable.ArrayBuffer
  *   [[GeometryUDT]] should have been expanded.
  * @param convertTz
  *   the optional time zone to convert to int96 data
- * @param datetimeRebaseSpec
- *   the specification of rebasing date/timestamp from Julian to Proleptic Gregorian calendar:
- *   mode + optional original time zone
- * @param int96RebaseSpec
- *   the specification of rebasing INT96 timestamp from Julian to Proleptic Gregorian calendar
+ * @param datetimeRebaseMode
+ *   the mode of rebasing date/timestamp from Julian to Proleptic Gregorian calendar
+ * @param int96RebaseMode
+ *   the mode of rebasing INT96 timestamp from Julian to Proleptic Gregorian calendar
  * @param parameters
  *   Options for reading GeoParquet files. For example, if legacyMode is enabled or not.
  * @param updater
@@ -94,8 +93,8 @@ private[parquet] class GeoParquetRowConverter(
     parquetType: GroupType,
     catalystType: StructType,
     convertTz: Option[ZoneId],
-    datetimeRebaseSpec: RebaseSpec,
-    int96RebaseSpec: RebaseSpec,
+    datetimeRebaseMode: LegacyBehaviorPolicy.Value,
+    int96RebaseMode: LegacyBehaviorPolicy.Value,
     parameters: Map[String, String],
     updater: ParentContainerUpdater)
     extends ParquetGroupConverter(updater)
@@ -149,13 +148,13 @@ private[parquet] class GeoParquetRowConverter(
   def currentRecord: InternalRow = currentRow
 
   private val dateRebaseFunc =
-    DataSourceUtils.createDateRebaseFuncInRead(datetimeRebaseSpec.mode, "Parquet")
+    GeoDataSourceUtils.creteDateRebaseFuncInRead(datetimeRebaseMode, "Parquet")
 
   private val timestampRebaseFunc =
-    DataSourceUtils.createTimestampRebaseFuncInRead(datetimeRebaseSpec, "Parquet")
+    GeoDataSourceUtils.creteTimestampRebaseFuncInRead(datetimeRebaseMode, "Parquet")
 
   private val int96RebaseFunc =
-    DataSourceUtils.createTimestampRebaseFuncInRead(int96RebaseSpec, "Parquet INT96")
+    GeoDataSourceUtils.creteTimestampRebaseFuncInRead(int96RebaseMode, "Parquet INT96")
 
   // Converters for each field.
   private[this] val fieldConverters: Array[Converter with HasParentContainerUpdater] = {
@@ -247,7 +246,7 @@ private[parquet] class GeoParquetRowConverter(
       case ByteType =>
         new ParquetPrimitiveConverter(updater) {
           override def addInt(value: Int): Unit =
-            updater.setByte(value.asInstanceOf[PhysicalByteType#InternalType])
+            updater.setByte(value.asInstanceOf[ByteType#InternalType])
 
           override def addBinary(value: Binary): Unit = {
             val bytes = value.getBytes
@@ -260,7 +259,7 @@ private[parquet] class GeoParquetRowConverter(
       case ShortType =>
         new ParquetPrimitiveConverter(updater) {
           override def addInt(value: Int): Unit =
-            updater.setShort(value.asInstanceOf[PhysicalShortType#InternalType])
+            updater.setShort(value.asInstanceOf[ShortType#InternalType])
         }
 
       // For INT32 backed decimals
@@ -315,6 +314,25 @@ private[parquet] class GeoParquetRowConverter(
           }
         }
 
+      case TimestampNTZType
+          if canReadAsTimestampNTZ(parquetType) &&
+            parquetType.getLogicalTypeAnnotation
+              .asInstanceOf[TimestampLogicalTypeAnnotation]
+              .getUnit == TimeUnit.MICROS =>
+        new ParquetPrimitiveConverter(updater)
+
+      case TimestampNTZType
+          if canReadAsTimestampNTZ(parquetType) &&
+            parquetType.getLogicalTypeAnnotation
+              .asInstanceOf[TimestampLogicalTypeAnnotation]
+              .getUnit == TimeUnit.MILLIS =>
+        new ParquetPrimitiveConverter(updater) {
+          override def addLong(value: Long): Unit = {
+            val micros = DateTimeUtils.millisToMicros(value)
+            updater.setLong(micros)
+          }
+        }
+
       case DateType =>
         new ParquetPrimitiveConverter(updater) {
           override def addInt(value: Int): Unit = {
@@ -370,8 +388,8 @@ private[parquet] class GeoParquetRowConverter(
           parquetType.asGroupType(),
           t,
           convertTz,
-          datetimeRebaseSpec,
-          int96RebaseSpec,
+          datetimeRebaseMode,
+          int96RebaseMode,
           parameters,
           wrappedUpdater)
 
@@ -382,6 +400,17 @@ private[parquet] class GeoParquetRowConverter(
     }
   }
 
+  // Only INT64 column with Timestamp logical annotation `isAdjustedToUTC=false`
+  // can be read as Spark's TimestampNTZ type. This is to avoid mistakes in reading the timestamp
+  // values.
+  private def canReadAsTimestampNTZ(parquetType: Type): Boolean =
+    schemaConverter.isTimestampNTZEnabled() &&
+      parquetType.asPrimitiveType().getPrimitiveTypeName == INT64 &&
+      parquetType.getLogicalTypeAnnotation.isInstanceOf[TimestampLogicalTypeAnnotation] &&
+      !parquetType.getLogicalTypeAnnotation
+        .asInstanceOf[TimestampLogicalTypeAnnotation]
+        .isAdjustedToUTC
+
   /**
    * Parquet converter for strings. A dictionary is used to minimize string decoding cost.
    */
